summaryrefslogtreecommitdiff
path: root/sw/inc/fesh.hxx
diff options
context:
space:
mode:
authorNoel Grandin <noel.grandin@collabora.co.uk>2017-03-17 14:15:30 +0200
committerNoel Grandin <noel.grandin@collabora.co.uk>2017-03-20 06:52:34 +0000
commitd99d143900081dd14e070c7373ba204739d80496 (patch)
tree72fb5e8523e29399d0aff96d3a6fb37dafeaabd6 /sw/inc/fesh.hxx
parent8e5437ea859e78f7de2730bfa60ab6d27534f286 (diff)
convert RndStdIds to scoped enum
Change-Id: I029ad67dfcbc40f3953adf485957efcbd97f23d0 Reviewed-on: https://gerrit.libreoffice.org/35328 Tested-by: Jenkins <ci@libreoffice.org> Reviewed-by: Noel Grandin <noel.grandin@collabora.co.uk>
Diffstat (limited to 'sw/inc/fesh.hxx')
-rw-r--r--sw/inc/fesh.hxx8
1 files changed, 4 insertions, 4 deletions
diff --git a/sw/inc/fesh.hxx b/sw/inc/fesh.hxx
index d3f2db36c79d..5995c6288e83 100644
--- a/sw/inc/fesh.hxx
+++ b/sw/inc/fesh.hxx
@@ -512,9 +512,9 @@ public:
void EndTextEdit(); ///< Deletes object if required.
- /** Anchor type of selected object, -1 if ambiguous or in case of frame selection.
- Else FLY_AT_PAGE or FLY_AT_PARA resp. from frmatr.hxx. */
- short GetAnchorId() const;
+ /** Anchor type of selected object, RndStdIds::UNKNOWN if ambiguous or in case of frame selection.
+ Else RndStdIds::FLY_AT_PAGE or RndStdIds::FLY_AT_PARA. */
+ RndStdIds GetAnchorId() const;
/** Process of creating draw objects. At the beginning object type is passed.
At the end a Cmd can be passed. Here, SDRCREATE_RESTRAINTEND for end
@@ -549,7 +549,7 @@ public:
/** frmatr.hxx. Here no enum because of dependencies.
bool value only for internal use! Anchor is newly set according
to current document position. Anchor is not re-set. */
- void ChgAnchor( int eAnchorId, bool bSameOnly = false,
+ void ChgAnchor( RndStdIds eAnchorId, bool bSameOnly = false,
bool bPosCorr = true );
bool SetDrawingAttr( SfxItemSet &rSet );